---
name: Bug report
about: Create a report to help us improve
title: "<select-one: 🐛 (bug) | ⚡ (performance/memory)> <nice descriptive title>"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots **
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - Operating System: [e.g. Windows, MacOS, FreeBSD, Linux, etc...]
 - `clouddrift` library version [e.g. v0.32.0, v0.30.0]

**Additional context**
Add any other context about the problem here. Things that fit here are additional details you want to add or a log dump.
